@@ -25,6 +25,7 @@ import boto3
 from prometheus_client import \
     CollectorRegistry, Counter, Gauge, Summary, \
     push_to_gateway, write_to_textfile, start_http_server, exposition
+import redis
 
 
 @singleton
@@ -144,7 +145,8 @@ logger = logging.getLogger(__name__)
 
 consul_keys = {"clickhouse": "env/databases/clickhouse", "kafka": "env/databases/kafka",
                "ms-azure-se": "env/databases/ms-azure-se", "loki": "env/databases/loki",
-               "greenplum": "env/databases/greenplum", "storage": "env/databases/storage"}
+               "greenplum": "env/databases/greenplum", "storage": "env/databases/storage",
+               "redis": "env/databases/redis"}
 services = {
     "consul": {},
     "aio_consul": {},
@@ -169,6 +171,7 @@ services = {
     "aiostorage_resource": {},
     "storage_client": {},
     "storage_resource": {},
+    "redis_client": {}
 }
 
 
@@ -285,8 +288,10 @@ class Factory:
             del kwargs["type"]
 
         args = []
-        args.append(config["url"] if "url" not in kwargs else kwargs["url"])
+        #args.append(config["url"] if "url" not in kwargs else kwargs["url"])
 
+        kwargs["host"] = config["url"] if not ("host" in kwargs) else kwargs["host"]
+        kwargs["host"] = kwargs["host"] if not ("url" in kwargs) else kwargs["url"]
         kwargs["port"] = config["port"] if not ("port" in kwargs) else kwargs["port"]
         kwargs["user"] = secrets["user"] if not ("user" in kwargs) else kwargs["user"]
         kwargs["password"] = secrets["password"] if not ("password" in kwargs) else kwargs["password"]
@@ -508,3 +513,13 @@ class Factory:
         service_name = "aiostorage_client"
         return self._storage_driver(aioboto3.Session().client, service_name, kwargs)
 
+    def redis_client(self, **kwargs):
+        service_name = "redis_client"
+        instance_name = self.def_instance_name if not self.key_istance_name in kwargs else kwargs[self.key_istance_name]
+        scrts = self.secrets["redis"]
+        cnfg = self.config["redis"]
+        kwargs["host"] = cnfg["url"] if not "url" in kwargs else kwargs["url"]
+        kwargs["password"] = scrts["password"] if not "password" in kwargs else kwargs["password"]
+        kwargs["port"] = cnfg["port"] if not "port" in kwargs else kwargs["port"]
+        kwargs["db"] = cnfg["db"] if not "db" in kwargs else kwargs["db"]
+        return self.get_instance(redis.Redis, service_name, instance_name, [], kwargs)
